@@ -64,12 +64,22 @@ class Controller(object):
     #. As developer you create the method that knows how to handle **/blog/** url.
     #. Write your view.
 
+    You can also map multiple routes for the same controller:
+
+    .. code-block python
+
+        @ControllerProvider()
+        class SimpleExample(BaseController):
+            @Controller(url=["/url1$", "/url2$")
+            def handle_urls(self, request):
+                # your logic comes here
+
     Below you can find the design for MVC provided by **Fantastico** framework:
 
     .. image:: /images/core/mvc.png'''
 
     _SUPPORTED_VERBS = ["get", "head", "post", "put", "delete", "trace", "options", "connect", "patch"]
-    _REGISTERED_ROUTES = {}
+    _REGISTERED_ROUTES = []
 
     @property
     def url(self):
@@ -97,7 +107,11 @@ class Controller(object):
         return self._fn_handler
 
     def __init__(self, url, method="GET", models=None, **kwargs):
-        self._url = url
+        if isinstance(url, str):
+            self._url = [url]
+        elif isinstance(url, list):
+            self._url = url
+
         self._method = None
 
         if isinstance(method, str):
@@ -176,7 +190,7 @@ class Controller(object):
 
         self._fn_handler = new_handler
 
-        self.get_registered_routes()[self.url] = self
+        self.get_registered_routes().append(self)
 
         return self._fn_handler
 
